<?php

namespace Drupal\bitly_shortener\Services;

use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * BitlyShortenerServices.
 */
class BitlyShortenerServices implements BitlyShortenerServicesInterface {

  /**
   * Protected configFactory variable.
   *
   * @var Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * Get shortener url.
   */
  public function shortener($url) {

    if (($this->configFactory->get('bitly_shortener.settings')->get('bitly_shortener_enable') === 0)
        && !empty($this->configFactory->get('bitly_shortener.settings')->get('bitly_shortener_token')) ) {
      return $url;
    }

    $bitly_token = $this->configFactory->get('bitly_shortener.settings')->get('bitly_shortener_token');

    try {
      $api_url = 'https://api-ssl.bitly.com/v4/bitlinks';
      $data = [
        'long_url' => $url
      ];
      $payload = json_encode($data);
      $header = [
        'Authorization: Bearer ' . $bitly_token,
        'Content-Type: application/json',
        'Content-Length: ' . strlen($payload)
      ];

      $ch = curl_init($api_url);
      curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
      curl_setopt($ch, CURLOPT_POSTFIELDS, $payload);
      curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
      curl_setopt($ch, CURLOPT_HTTPHEADER, $header);
      $result = curl_exec($ch);
      $resultToJson = json_decode($result);

      if (isset($resultToJson->link)) {
        return $resultToJson->link;
      }
      else {
        \Drupal::messenger()->addMessage('Bitly shortener invalid access token.', 'warning');
        return $url;
      }

    } catch(Exception $e) {
      return $e->getMessage();
    }

  }

}
